.. -*- mode: rst -*-

Yellowbrick for Teachers
========================

For teachers and students of machine learning, Yellowbrick can be used as a framework for teaching and understanding a large variety of algorithms and methods. In fact, Yellowbrick grew out of teaching data science courses at Georgetown's School of Continuing Studies!

The following slide deck presents an approach to teaching students about the machine learning workflow (the model selection triple), including:

- feature analysis
- feature importances
- feature engineering
- algorithm selection
- model evaluation for classification and regression
- cross-validation
- hyperparameter tuning
- the scikit-learn API

.. raw:: html

    <iframe src="https://www.slideshare.net/slideshow/embed_code/key/3ltBl9qX9w7uXk" width="595" height="485" frameborder="0" marginwidth="0" marginheight="0" scrolling="no" style="border:1px solid #CCC; border-width:1px; margin-bottom:5px; max-width: 100%;" allowfullscreen> </iframe> <div style="margin-bottom:5px"> <strong> <a href="//www.slideshare.net/RebeccaBilbro/learning-machine-learning-with-yellowbrick" title="Learning machine learning with Yellowbrick" target="_blank">Learning machine learning with Yellowbrick</a> </strong> from <strong><a href="//www.slideshare.net/RebeccaBilbro" target="_blank">Rebecca Bilbro</a></strong> </div>


Teachers are welcome to `download the slides <https://www.slideshare.net/RebeccaBilbro/learning-machine-learning-with-yellowbrick>`_ via SlideShare as a PowerPoint deck, and to add them to their course materials to assist in teaching these important concepts.
